# author: delta1037
# Date: 2022/01/08
# mail:geniusrabbit@qq.com

__author__ = "delta1037 <geniusrabbit@qq.com>"
__version__ = "1.0"

# 临时存放文件夹
TMP_DIR = "./.tmp/"

# Markdown的分割条语法
MD_DIVIDER = "------"

# 日志输出模式
DUMP_MODE_DEBUG = 0
DUMP_MODE_DEFAULT = 1
DUMP_MODE_SILENT = 2
DUMP_MODE = DUMP_MODE_DEBUG

# 导出的类型
DUMP_TYPE_BLOCK = 1
DUMP_TYPE_PAGE = 2
DUMP_TYPE_DB_TABLE = 4

# 解析的类型：分为Markdown和纯文本
PARSER_TYPE_MD = 0
PARSER_TYPE_PLAIN = 2
